library(dplyr)
library(ggplot2)

illustration_logistique = function(data,indep,dep,n_int=5,log_reg=FALSE){
y_lab = paste(c("probability of ",substitute(dep)), collapse = "")
x_lab = substitute(indep)
data = data %>% mutate(indep2 = cut(indep, breaks = quantile(indep, probs = seq(0 , 1 , 1/n_int)),labels = quantile(indep, probs = seq(0 , 1 , 1/n_int))[-(n_int+1)],include.lowest = TRUE))

if (min(as.numeric(dep)) ==1)
{data = data %>% mutate(dep = as.numeric(dep)-1)}
agg = group_by(data,indep2)
table = summarise(agg,num.types = n(),counts = sum(dep))

x= (quantile(indep, probs = seq(0 , 1 , 1/n_int))[-1]+quantile(indep, probs = seq(0 , 1 , 1/n_int))[-(n_int+1)])/2
mean_data = data.frame(x= x, y = as.matrix(table[3])/as.matrix(table[2]))

plt = ggplot(data, aes(indep,dep))

plt = plt + geom_point()

plt = plt  + geom_point(data = mean_data, aes(x = x, y = counts, colour ="red"),size = 3,show.legend = FALSE)
plt = plt + labs(x = x_lab, y = y_lab) +guides(colour=FALSE) + geom_vline(xintercept = quantile(indep, probs = seq(0 , 1 , 1/n_int)), linetype = "dashed", colour = "red")
if (log_reg)
{plt = plt  +geom_smooth(method = "glm", method.args = list(family = "binomial")) 
}
return(plt)}


illustration_poisson = function(data,indep,dep,n_int=5,log_pois=FALSE){
  y_lab = paste(c("mean of ",substitute(dep)), collapse = "")
  x_lab = substitute(indep)
  data = data %>% mutate(group = cut(indep, breaks = quantile(indep, probs = seq(0 , 1 , 1/n_int)),labels = c(1:(n_int)),include.lowest = TRUE))

  # agg = group_by(data,factor(group))
  # table = summarise(agg,mean= mean(dep))
  # print(table)
  
  
  x= (quantile(indep, probs = seq(0 , 1 , 1/n_int))[-1]+quantile(indep, probs = seq(0 , 1 , 1/n_int))[-(n_int+1)])/2
  means = rep(0,n_int)
  for (j in 1:5){
    means[j] = mean(dep[data$group==j])
  }
  mean_data = data_frame(x , means)
  
  plt = ggplot(data, aes(indep,dep))
  
  plt = plt + geom_point()
  
  plt = plt  + geom_point(data = mean_data, aes(x = x, y = means , colour ="red"),size = 3,show.legend = FALSE)
  plt = plt + labs(x = x_lab, y = y_lab) +guides(colour=FALSE) + geom_vline(xintercept = quantile(indep, probs = seq(0 , 1 , 1/n_int)), linetype = "dashed", colour = "red")
  if (log_pois)
  {plt = plt  +geom_smooth(method = "glm", method.args = list(family = "poisson")) 
  }
  return(plt)}